==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/src/Base/Common/Equal.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  Equal.cxx
 *  @brief Abstract top-level class for all Equal
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: Equal.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include "Equal.hxx"
#include "PersistentObjectFactory.hxx"

namespace OpenTURNS {

  namespace Base {

    namespace Common {

      CLASSNAMEINIT(Equal);

      static Common::Factory<Equal> RegisteredFactory("Equal");

      /* Default constructor */
      Equal::Equal()
	: ComparisonOperatorImplementation()
      {
	// Initialize any other class members here
	// At last, allocate memory space if needed, but go to destructor to free it
      }

      /* String converter */
      String Equal::str() const {
	return OSS() << "class=" << Equal::GetClassName()
		     << " name=" << getName();
      }
  

      /* Here is the interface that all derived class must implement */

      /* Virtual constructor */
      Equal * Equal::clone() const
      {
	return new Equal(*this);
      }

      /* Return true if comparison succeeds */
      Bool Equal::operator() (NumericalScalar a, NumericalScalar b) const
      {
	return (a == b);
      }

      /* Method save() stores the object through the StorageManager */
      void Equal::save(const StorageManager::Advocate & adv) const
      {
	ComparisonOperatorImplementation::save(adv);
      }


      /* Method load() reloads the object from the StorageManager */
      void Equal::load(const StorageManager::Advocate & adv)
      {
	ComparisonOperatorImplementation::load(adv);
      }




    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Base/Common/Equal.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  Equal.cxx
 *  @brief Abstract top-level class for all Equal
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (jeu. 04 févr. 2010) $
 *  Id:      $Id: Equal.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include "Equal.hxx"
#include "PersistentObjectFactory.hxx"

namespace OpenTURNS {

  namespace Base {

    namespace Common {

      CLASSNAMEINIT(Equal);

      static Common::Factory<Equal> RegisteredFactory("Equal");

      /* Default constructor */
      Equal::Equal()
	: ComparisonOperatorImplementation()
      {
	// Nothing to do
      }

      /* String converter */
      String Equal::__repr__() const {
	return OSS() << "class=" << Equal::GetClassName()
		     << " name=" << getName();
      }
  

      /* Here is the interface that all derived class must implement */

      /* Virtual constructor */
      Equal * Equal::clone() const
      {
	return new Equal(*this);
      }

      /* Return true if comparison succeeds */
      Bool Equal::operator() (NumericalScalar a, NumericalScalar b) const
      {
	return (a == b);
      }

      /* Method save() stores the object through the StorageManager */
      void Equal::save(StorageManager::Advocate & adv) const
      {
	ComparisonOperatorImplementation::save(adv);
      }


      /* Method load() reloads the object from the StorageManager */
      void Equal::load(StorageManager::Advocate & adv)
      {
	ComparisonOperatorImplementation::load(adv);
      }




    } /* namespace Common */
  } /* namespace Base */
} /* namespace OpenTURNS */
